function volterra2_analytic
%
%  Solution to a Volterra Equation of the Second Kind
%
%  The Volterra Equations have four parameters
%
%  the lower limit of integration, a
%  the constant prefactor outside the integral, lam
%  the function outside the integral, f, given in a function at the bottom of this file
%  the kernel, kernelorig, given in a function at the bottom of this file
%
%  This code gives teh analytic solution to a=0, lam=-1, f=e=^x and N=e^(x-y)
%
%  Author:  David Keffer, University of Tennessee, Department of Chemical Engineering
%
clf
time_01 = cputime;
a = 0;
lam = -1;
%
%  set up a grid of x values
%
xstart = 0.0;
xf = 1.0;
dx = 0.01;
nx =(xf-xstart)/dx + 1;
x = zeros(nx,1);
for i = 1:1:nx
   x(i) = xstart + (i-1)*dx;
end
%
%  let's run different runs where we truncate the resolvent
%  kernel at different points just to see the effect
%
nruns = 10;
ncutoff=[1;2;3;4;5;6;7;8;9;10]';
phi = zeros(nx,nruns);
%
for j = 1:1:nruns
%
%  calculate and plot purely analytic phi
%
	for i = 1:1:nx
      xi = x(i);
      for k = 0:1:ncutoff(j)
         phi(i,j) = phi(i,j) + (-xi)^k/factorial(k);     
      end
      phi(i,j) = phi(i,j)*f(xi);
   end
   %
   % plot
   %
	if (j==1)
     plot (x,phi(:,j),'k-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (j==2)
     plot (x,phi(:,j),'r-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (j==3)
     plot (x,phi(:,j),'b-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (j==4)
     plot (x,phi(:,j),'g-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (j==5)
     plot (x,phi(:,j),'m-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (j==6)
     plot (x,phi(:,j),'k:'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (j==7)
     plot (x,phi(:,j),'r:'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (j==8)
     plot (x,phi(:,j),'b:'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (j==9)
     plot (x,phi(:,j),'g:'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (j==10)
     plot (x,phi(:,j),'m:'), xlabel( 'x' ), ylabel ( 'phi' )
 	else
     plot (x,phi(:,j),'k-'), xlabel( 'x' ), ylabel ( 'phi' )
	end
	hold on
	fprintf (1,'FINISHED CALCULATING THE %2i RUN where ncutoff = %4i \n', j, ncutoff(j));
end
hold off
phi

function y = f(x)
y = exp(x);

function y = factorial(x)
	fact = 1;
	for i = 1:1:x
   	fact = fact*i;
   end
	y = fact;