function volterra2_nonlinear
clear all;
close all;
%
%  Solution to a Nonlinear Volterra Equation of the Second Kind
%
%  The Volterra Equations have four parameters
%
%  the lower limit of integration, a
%  the constant prefactor outside the integral, lam
%  the function outside the integral, f, given in a function at the bottom of this file
%  the kernel, kernelorig, given in a function at the bottom of this file
%  This code gives the numeric solution to a=0, lam=-1, f=e=^x and K=sin(phi)
%
%  Author:  David Keffer, University of Tennessee, Department of Chemical Engineering
%
clf
a = 0.0;
lam = -1.0;
%
%  set up a grid of x values
%
xstart = 0.0;
xf = 1.0;
%
%  USING SUCCESSIVE APPROXIMATIONS
%
ninterval = 20;
npoints = ninterval+1;
dx = (xf-xstart)/ninterval;
x = zeros(npoints,1);
for i = 1:1:npoints
   x(i) = xstart + (i-1)*dx;
end
nruns = 8;
ncutoff=[1;2;3;4;5;6;7;8;9;10]';
phi = zeros(npoints,ncutoff(nruns));
%
%  initialize phi(:,1)
%
for i = 1:1:npoints
   phi(i,1) = f(x(i));
end
%plot (x,phi(:,1),'k-'), xlabel( 'x' ), ylabel ( 'phi' );
%hold on;
%
%  start iteration loop
%
jrun = 1;
for jj = 2:1:ncutoff(nruns)+1
   jjm1 = jj-1;
   dxh = 0.5*dx;
   phi(1,jj) = f(x(1));
   for k = 2:1:npoints
   	kernphi1 = kern(phi(1,jjm1),x(k),x(1));
   	integral_mid = 0.0;
   	for i = 2:1:k
      	integral_mid = integral_mid + kern(phi(i,jjm1),x(k),x(i));
      end
      integral = dxh*( kernphi1 + 2.0*integral_mid - kern(phi(i,jjm1),x(k),x(i)) );
      phi(k,jj) = f(x(k)) + lam*integral;
      %fprintf(1, '%e %e %e \n',phi(k,jj),f(x(k)),lam*integral )
   end
   %
   % plot
   %
   if ( jjm1 == ncutoff(jrun) )
      jrun = jrun + 1;
	if (jj==1)
     plot (x,phi(:,jj),'k-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==2)
     plot (x,phi(:,jj),'r-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==3)
     plot (x,phi(:,jj),'b-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==4)
     plot (x,phi(:,jj),'g-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==5)
     plot (x,phi(:,jj),'m-'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==6)
     plot (x,phi(:,jj),'k:'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==7)
     plot (x,phi(:,jj),'r:'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==8)
     plot (x,phi(:,jj),'b:'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==9)
     plot (x,phi(:,jj),'g:'), xlabel( 'x' ), ylabel ( 'phi' )
  	elseif (jj==10)
     plot (x,phi(:,jj),'m:'), xlabel( 'x' ), ylabel ( 'phi' )
 	else
     plot (x,phi(:,jj),'k-'), xlabel( 'x' ), ylabel ( 'phi' )
	end
	hold on
	fprintf (1,'THE %2i RUN where nintervals = %4i and iteration = %4i, phi(%5.2f) = %5.2f \n', jjm1, ninterval, ncutoff(jrun-1), x(npoints), phi(npoints,ncutoff(jrun))  );
end   
end
hold off

function y = f(x)
y = exp(x);

function z = kern(phi,x,y)
z = exp(x-y)*phi;
