function volterra2_nonlinear
clear all;
close all;
%
%  Solution to a Nonlinear Volterra Equation of the Second Kind
%
%  The Volterra Equations have four parameters
%
%  the lower limit of integration, a
%  the constant prefactor outside the integral, lam
%  the function outside the integral, f, given in a function at the bottom of this file
%  the kernel, kernelorig, given in a function at the bottom of this file
%  This code gives the numeric solution to a=0, lam=-1, f=e=^x and K=sin(phi)
%
%  Author:  David Keffer, University of Tennessee, Department of Chemical Engineering
%
clf
a = 0.0;
lam = -24.0;
%
%  set up a grid of x values
%
xstart = 0.0;
xf = 1.0;
%
%  USING SUCCESSIVE APPROXIMATIONS
%
ninterval = 50;
npoints = ninterval+1;
dx = (xf-xstart)/ninterval;
x = zeros(npoints,1);
for i = 1:1:npoints
   x(i) = xstart + (i-1)*dx;
end
maxit = 100;
phi = zeros(npoints,maxit);
%
%  initialize phi(:,1)
%
for i = 1:1:npoints
   phi(i,1) = f(x(i));
end
%plot (x,phi(:,1),'k-'), xlabel( 'x' ), ylabel ( 'phi' );
%hold on;
%
%  start iteration loop
%
err = 100.0;
tol = 1.0e-8;
icount = 1;
%
dxh = 0.5*dx;
fac1 = lam*dxh;
fac2 = 2*fac1;
while (err > tol & icount <= maxit)
   icount = icount + 1;
   jj = icount;
   jjm1 = jj-1;
   dxh = 0.5*dx;
   phi(1,jj) = f(x(1));
   for k = 2:1:npoints
   	kernphi1 = kern(phi(1,jjm1),x(k),x(1));
   	integral_mid = 0.0;
   	for i = 2:1:k
      	integral_mid = integral_mid + kern(phi(i,jjm1),x(k),x(i));
      end
      integral = dxh*( kernphi1 + 2.0*integral_mid - kern(phi(i,jjm1),x(k),x(i)) );
      phi(k,jj) = f(x(k)) + lam*integral;
      %fprintf(1, '%e %e %e \n',phi(k,jj),f(x(k)),lam*integral )
   end
   R = phi(:,jj) - phi(:,jjm1);
   err = sqrt(sum(R.*R)/npoints);
   %
   % plot
   %
   iplot = 1;
   if ( iplot == 1 )
		if (jj==1)
     		plot (x,phi(:,jj),'k-'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==2)
         plot (x,phi(:,jj),'k-'), xlabel( 'x' ), ylabel ( 'phi' )
         hold on;
     		plot (x,phi(:,jj),'r-'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==3)
     		plot (x,phi(:,jj),'b-'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==4)
     		plot (x,phi(:,jj),'g-'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==5)
     		plot (x,phi(:,jj),'m-'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==6)
     		plot (x,phi(:,jj),'k:'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==7)
     		plot (x,phi(:,jj),'r:'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==8)
     		plot (x,phi(:,jj),'b:'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==9)
     		plot (x,phi(:,jj),'g:'), xlabel( 'x' ), ylabel ( 'phi' )
  		elseif (jj==10)
     		plot (x,phi(:,jj),'m:'), xlabel( 'x' ), ylabel ( 'phi' )
 		else
     		plot (x,phi(:,jj),'k-'), xlabel( 'x' ), ylabel ( 'phi' )
		end
		hold on
	end   
end
hold off
figure(2)
jj = icount;
plot (x,phi(:,jj),'k-'), xlabel( 'x' ), ylabel ( 'phi' )
title('converged solution');
format long e
phi(:,icount)
fprintf(1, 'It took %i iterations to reach an error of %e \n', icount-1, err);

function y = f(x)
y = exp(x);

function z = kern(phi,x,y)
z = sin(phi);
